@@ -6,7 +6,7 @@
 # TheVirtualBrain-Scientific Package (for simulators). See content of the
 # documentation-folder for more details. See also http://www.thevirtualbrain.org
 #
-# (c) 2012-2020, Baycrest Centre for Geriatric Care ("Baycrest") and others
+# (c) 2012-2022, Baycrest Centre for Geriatric Care ("Baycrest") and others
 #
 # This program is free software: you can redistribute it and/or modify it under the
 # terms of the GNU General Public License as published by the Free Software Foundation,
@@ -30,16 +30,16 @@
 
 import os
 from abc import abstractmethod
+
 from tvb.adapters.analyzers.matlab_worker import MatlabWorker
-from tvb.basic.profile import TvbProfile
-from tvb.core.adapters.abcadapter import ABCAsynchronous, ABCAdapterForm
-from tvb.core.entities.filters.chain import FilterChain
 from tvb.adapters.datatypes.db.connectivity import ConnectivityIndex
 from tvb.adapters.datatypes.db.graph import ConnectivityMeasureIndex
 from tvb.adapters.datatypes.db.mapped_value import ValueWrapperIndex
-from tvb.core.entities.load import load_entity_by_gid
+from tvb.adapters.datatypes.h5.mapped_value_h5 import ValueWrapper
+from tvb.basic.profile import TvbProfile
+from tvb.core.adapters.abcadapter import ABCAdapterForm, ABCAdapter
+from tvb.core.entities.filters.chain import FilterChain
 from tvb.core.entities.model.model_operation import AlgorithmTransientGroup
-from tvb.core.neocom import h5
 from tvb.core.neotraits.forms import TraitDataTypeSelectField
 from tvb.core.neotraits.view_model import ViewModel, DataTypeGidAttr
 from tvb.core.utils import extract_matlab_doc_string
@@ -62,19 +62,19 @@ LABEL_CONN_WEIGHTED_UNDIRECTED = "Weighted undirected connection matrix"
 def bct_description(mat_file_name):
     return extract_matlab_doc_string(os.path.join(BCT_PATH, mat_file_name))
 
-class BaseBCTModel(ViewModel):
 
+class BaseBCTModel(ViewModel):
     connectivity = DataTypeGidAttr(
         linked_datatype=Connectivity,
         label='Connectivity',
     )
 
+
 class BaseBCTForm(ABCAdapterForm):
-    def __init__(self, prefix='', project_id=None, draw_ranges=True):
-        super(BaseBCTForm, self).__init__(prefix, project_id, draw_ranges)
-        self.connectivity = TraitDataTypeSelectField(BaseBCTModel.connectivity, self,
-                                                     name="connectivity", conditions=self.get_filters(),
-                                                     has_all_option=True)
+    def __init__(self):
+        super(BaseBCTForm, self).__init__()
+        self.connectivity = TraitDataTypeSelectField(BaseBCTModel.connectivity, name="connectivity",
+                                                     conditions=self.get_filters(), has_all_option=True)
 
     @staticmethod
     def get_required_datatype():
@@ -99,14 +99,15 @@ class BaseUnidirectedBCTForm(BaseBCTForm):
     def get_filters():
         return FilterChain(fields=[FilterChain.datatype + '.undirected'], operations=["=="], values=['1'])
 
-class BaseBCT(ABCAsynchronous):
+
+class BaseBCT(ABCAdapter):
     """
     Interface between Brain Connectivity Toolbox of Olaf Sporns and TVB Framework.
     This adapter requires BCT deployed locally, and Matlab or Octave installed separately of TVB.
     """
 
     def __init__(self):
-        ABCAsynchronous.__init__(self)
+        ABCAdapter.__init__(self)
         self.matlab_worker = MatlabWorker()
 
     @staticmethod
@@ -127,13 +128,12 @@ class BaseBCT(ABCAsynchronous):
         return 0
 
     def get_connectivity(self, view_model):
-        conn_index = load_entity_by_gid(view_model.connectivity.hex)
-        return h5.load_from_index(conn_index)
+        return self.load_traited_by_gid(view_model.connectivity)
 
     def execute_matlab(self, matlab_code, data):
         self.matlab_worker.add_to_path(BCT_PATH)
         self.log.info("Starting execution of MATLAB code:" + matlab_code)
-        runcode, matlablog, result = self.matlab_worker.matlab(matlab_code, data=data)
+        runcode, matlablog, result = self.matlab_worker.matlab(matlab_code, data=data, work_dir=self.get_storage_path())
         self.log.debug("Code run in MATLAB: " + str(runcode))
         self.log.debug("MATLAB log: " + str(matlablog))
         self.log.debug("Finished MATLAB execution:" + str(result))
@@ -146,21 +146,21 @@ class BaseBCT(ABCAsynchronous):
         measure.title = title
         measure.label_x = label_x
         measure.label_y = label_y
-        return h5.store_complete(measure, self.storage_path)
+        return self.store_complete(measure)
 
     def build_float_value_wrapper(self, result, key, title=""):
-        value = ValueWrapperIndex()
-        value.data_value = float(result[key])
+        value = ValueWrapper()
+        value.data_value = str(float(result[key]))
         value.data_type = 'float'
         value.data_name = title
-        return value
+        return self.store_complete(value)
 
     def build_int_value_wrapper(self, result, key, title=""):
-        value = ValueWrapperIndex()
-        value.data_value = int(result[key])
+        value = ValueWrapper()
+        value.data_value = str(int(result[key]))
         value.data_type = 'int'
         value.data_name = title
-        return value
+        return self.store_complete(value)
 
     @abstractmethod
     def launch(self, view_model):
@@ -178,6 +178,7 @@ class BaseUndirected(BaseBCT):
     def launch(self, view_model):
         pass
 
+
 class ModularityOCSM(BaseBCT):
     """
     """
