@@ -6,7 +6,7 @@
 # TheVirtualBrain-Scientific Package (for simulators). See content of the
 # documentation-folder for more details. See also http://www.thevirtualbrain.org
 #
-# (c) 2012-2020, Baycrest Centre for Geriatric Care ("Baycrest") and others
+# (c) 2012-2022, Baycrest Centre for Geriatric Care ("Baycrest") and others
 #
 # This program is free software: you can redistribute it and/or modify it under the
 # terms of the GNU General Public License as published by the Free Software Foundation,
@@ -92,23 +92,38 @@ class BurstDAO(RootDAO):
         try:
             burst = self.session.query(BurstConfiguration).filter_by(id=burst_id).one()
             burst.project
+            return burst
+        except NoResultFound:
+            self.logger.debug("No burst found with id = {}".format(burst_id))
         except SQLAlchemyError as excep:
             self.logger.exception(excep)
-            burst = None
-        return burst
+        return None
 
-    def get_burst_for_operation_id(self, operation_id):
+    def get_burst_for_operation_id(self, operation_id, is_group=False):
         burst = None
         try:
-            burst = self.session.query(BurstConfiguration
-                                       ).filter(or_(BurstConfiguration.fk_simulation == operation_id,
-                                                    BurstConfiguration.fk_operation_group == operation_id)).first()
+            burst = self.get_burst_for_direct_operation_id(operation_id, is_group)
             if not burst:
                 burst = self.session.query(BurstConfiguration
-                                           ).join(DataType, DataType.fk_parent_burst == BurstConfiguration.id
+                                           ).join(DataType, DataType.fk_parent_burst == BurstConfiguration.gid
                                                   ).filter(DataType.fk_from_operation == operation_id).first()
         except NoResultFound:
             self.logger.debug("No burst found for operation id = %s" % (operation_id,))
         except SQLAlchemyError as excep:
             self.logger.exception(excep)
         return burst
+
+    def get_burst_for_direct_operation_id(self, operation_id, is_group=False):
+        burst = None
+        try:
+            if is_group:
+                burst = self.session.query(BurstConfiguration
+                                           ).filter(BurstConfiguration.fk_operation_group == operation_id).first()
+            else:
+                burst = self.session.query(BurstConfiguration
+                                           ).filter(BurstConfiguration.fk_simulation == operation_id).first()
+        except NoResultFound:
+            self.logger.debug("No direct burst found for operation id = %s" % (operation_id,))
+        except SQLAlchemyError as excep:
+            self.logger.exception(excep)
+        return burst
