@@ -6,7 +6,7 @@
 # TheVirtualBrain-Scientific Package (for simulators). See content of the
 # documentation-folder for more details. See also http://www.thevirtualbrain.org
 #
-# (c) 2012-2020, Baycrest Centre for Geriatric Care ("Baycrest") and others
+# (c) 2012-2022, Baycrest Centre for Geriatric Care ("Baycrest") and others
 #
 # This program is free software: you can redistribute it and/or modify it under the
 # terms of the GNU General Public License as published by the Free Software Foundation,
@@ -115,7 +115,9 @@ class OperationDAO(RootDAO):
             self.logger.exception(excep)
             return None
 
-    def get_operations(self, status=[STATUS_PENDING, STATUS_STARTED], algorithm_classname="SimulatorAdapter"):
+    def get_operations(self, status=None, algorithm_classname="SimulatorAdapter"):
+        if status is None:
+            status = [STATUS_PENDING, STATUS_STARTED]
         try:
             result = self.session.query(Operation).join(Algorithm) \
                 .filter(Algorithm.classname == algorithm_classname) \
@@ -125,6 +127,21 @@ class OperationDAO(RootDAO):
             self.logger.exception(excep)
             return None
 
+    def get_operations_for_hpc_job(self):
+        status = [STATUS_PENDING, STATUS_STARTED]
+        algorithm_classname = "SimulatorAdapter"
+        queue_full = False
+        try:
+            result = self.session.query(Operation).join(Algorithm) \
+                .filter(Algorithm.classname == algorithm_classname) \
+                .filter(Operation.status.in_(status)) \
+                .filter(Operation.queue_full == queue_full).all()
+            return result
+        except SQLAlchemyError as excep:
+            self.logger.exception(excep)
+            return None
+
+
     def is_upload_operation(self, operation_gid):
         """
         Returns True only if the operation with the given gid is an upload operation.
@@ -423,6 +440,14 @@ class OperationDAO(RootDAO):
     # ALGORITHM RELATED METHODS
     #
 
+    def get_all_algorithms(self):
+        try:
+            result = self.session.query(Algorithm).distinct().all()
+            return result
+        except SQLAlchemyError as ex:
+            self.logger.exception(ex)
+            return None
+
     def get_algorithm_by_id(self, algorithm_id):
         try:
             result = self.session.query(Algorithm).filter_by(id=algorithm_id).one()
