@@ -32,10 +32,10 @@ import abc
 import json
 import typing
 import uuid
-
 import numpy
 import scipy.sparse
-from tvb.basic.neotraits.api import HasTraits, Attr, NArray, Range
+
+from tvb.basic.neotraits.api import HasTraits, Attr, NArray, Range, TVBEnum
 from tvb.datatypes import equations
 from tvb.storage.h5.file.exceptions import MissingDataSetException
 
@@ -124,6 +124,17 @@ class Uuid(Scalar):
         return None
 
 
+class Enum(Scalar):
+    def store(self, val):
+        if val is not None:
+            self.owner.storage_manager.set_metadata({self.field_name: val.value})
+
+    def load(self):
+        metadata = self.owner.storage_manager.get_metadata()
+        if self.field_name in metadata:
+            return TVBEnum.string_to_enum(list(self.trait_attribute.field_type), str(metadata[self.field_name]))
+
+
 class DataSetMetaData(object):
     """
     simple container for dataset metadata
