@@ -98,7 +98,7 @@ class BurstService(object):
             burst_entity.finish_time = datetime.now()
             dao.store_entity(burst_entity)
             if store_h5_file:
-                self.update_burst_configuration_h5(burst_entity)
+                self.store_burst_configuration(burst_entity)
         except Exception:
             self.logger.exception("Could not correctly update Burst status and meta-data!")
             burst_entity.status = burst_status
@@ -106,7 +106,7 @@ class BurstService(object):
             burst_entity.finish_time = datetime.now()
             dao.store_entity(burst_entity)
             if store_h5_file:
-                self.update_burst_configuration_h5(burst_entity)
+                self.store_burst_configuration(burst_entity)
 
     def persist_operation_state(self, operation, operation_status, message=None):
         """
@@ -138,7 +138,7 @@ class BurstService(object):
         burst = dao.get_burst_by_id(burst_id)
         burst.name = new_name
         dao.store_entity(burst)
-        self.update_burst_configuration_h5(burst)
+        self.store_burst_configuration(burst)
 
     @staticmethod
     def get_available_bursts(project_id):
@@ -189,12 +189,6 @@ class BurstService(object):
         burst = dao.store_entity(burst)
         return burst
 
-    def update_burst_configuration_h5(self, burst_configuration):
-        # type: (BurstConfiguration) -> None
-        project = dao.get_project_by_id(burst_configuration.fk_project)
-        storage_path = self.storage_interface.get_project_folder(project.name, str(burst_configuration.fk_simulation))
-        self.store_burst_configuration(burst_configuration, storage_path)
-
     @staticmethod
     def load_burst_configuration(burst_config_id):
         # type: (int) -> BurstConfiguration
@@ -222,8 +216,9 @@ class BurstService(object):
         return dao.store_entity(burst_config)
 
     @staticmethod
-    def store_burst_configuration(burst_config, storage_path):
-        bc_path = h5.path_for(storage_path, BurstConfigurationH5, burst_config.gid)
+    def store_burst_configuration(burst_config):
+        project = dao.get_project_by_id(burst_config.fk_project)
+        bc_path = h5.path_for(burst_config.fk_simulation, BurstConfigurationH5, burst_config.gid, project.name)
         with BurstConfigurationH5(bc_path) as bc_h5:
             bc_h5.store(burst_config)
 
@@ -343,15 +338,23 @@ class BurstService(object):
         op_dir = StorageInterface().get_project_folder(operation.project.name, str(metric_operation.id))
         return op_dir, metric_operation
 
+    @staticmethod
+    def get_range_param_by_name(param_name, all_range_parameters):
+        for range_param in all_range_parameters:
+            if param_name == range_param.name:
+                return range_param
+
+        return None
+
     @staticmethod
     def handle_range_params_at_loading(burst_config, all_range_parameters):
         param1, param2 = None, None
         if burst_config.range1:
             param1 = RangeParameter.from_json(burst_config.range1)
-            param1.fill_from_default(all_range_parameters[param1.name])
+            param1.fill_from_default(BurstService.get_range_param_by_name(param1.name, all_range_parameters))
             if burst_config.range2 is not None:
                 param2 = RangeParameter.from_json(burst_config.range2)
-                param2.fill_from_default(all_range_parameters[param2.name])
+                param2.fill_from_default(BurstService.get_range_param_by_name(param2.name, all_range_parameters))
 
         return param1, param2
 
