@@ -6,7 +6,7 @@
 # TheVirtualBrain-Scientific Package (for simulators). See content of the
 # documentation-folder for more details. See also http://www.thevirtualbrain.org
 #
-# (c) 2012-2020, Baycrest Centre for Geriatric Care ("Baycrest") and others
+# (c) 2012-2022, Baycrest Centre for Geriatric Care ("Baycrest") and others
 #
 # This program is free software: you can redistribute it and/or modify it under the
 # terms of the GNU General Public License as published by the Free Software Foundation,
@@ -35,7 +35,7 @@
 import os
 import sys
 import json
-import datetime
+from datetime import datetime
 import uuid
 import urllib.request, urllib.parse, urllib.error
 from hashlib import md5
@@ -52,8 +52,9 @@ CHAR_SEPARATOR = "__"
 CHAR_SPACE = "--"
 CHAR_DRIVE = "-DriVe-"
 DRIVE_SEP = ":"
+
 COMPLEX_TIME_FORMAT = '%Y-%m-%d,%H-%M-%S.%f'
-# LESS_COMPLEX_TIME_FORMAT is also compatible with data exported from TVB 1.0. 
+# LESS_COMPLEX_TIME_FORMAT is also compatible with data exported from TVB 1.0.
 # This is only used as a fallback in the string to date conversion.
 LESS_COMPLEX_TIME_FORMAT = '%Y-%m-%d,%H-%M-%S'
 SIMPLE_TIME_FORMAT = "%m-%d-%Y"
@@ -85,7 +86,7 @@ def get_unique_file_name(storage_folder, file_name, try_number=0):
     """
     # TODO this method should be re-tought
     name, ext = os.path.splitext(file_name)
-    date = str(datetime.datetime.now())
+    date = str(datetime.now())
     date = date.replace(' ', '').replace(':', '').replace('.', '').replace('-', '')
     if try_number > 0:
         file_ = '%s-%s%s' % (name, date, ext)
@@ -102,29 +103,19 @@ def get_unique_file_name(storage_folder, file_name, try_number=0):
 
 ################## CONVERT related methods start here ###############
 
-def parse_json_parameters(parameters):
-    """
-    From JSON with Unicodes, return a dictionary having strings as keys.
-    Loading from DB a JSON will return instead of string keys, unicodes.
-    """
-    params = json.loads(parameters)
-    new_params = {}
-    for key, value in six.iteritems(params):
-        new_params[str(key)] = value
-    return new_params
-
-
 def string2date(string_input, complex_format=True, date_format=None):
     """Read date from string, after internal format"""
+    if string_input == 'None':
+        return None
     if date_format is not None:
-        return datetime.datetime.strptime(string_input, date_format)
+        return datetime.strptime(string_input, date_format)
     if complex_format:
         try:
-            return datetime.datetime.strptime(string_input, COMPLEX_TIME_FORMAT)
+            return datetime.strptime(string_input, COMPLEX_TIME_FORMAT)
         except ValueError:
             # For backwards compatibility with TVB 1.0
-            return datetime.datetime.strptime(string_input, LESS_COMPLEX_TIME_FORMAT)
-    return datetime.datetime.strptime(string_input, SIMPLE_TIME_FORMAT)
+            return datetime.strptime(string_input, LESS_COMPLEX_TIME_FORMAT)
+    return datetime.strptime(string_input, SIMPLE_TIME_FORMAT)
 
 
 def date2string(date_input, complex_format=True, date_format=None):
@@ -140,6 +131,24 @@ def date2string(date_input, complex_format=True, date_format=None):
     return date_input.strftime(SIMPLE_TIME_FORMAT)
 
 
+def string2bool(string_input):
+    """ Convert given string into boolean value."""
+    string_input = str(string_input).lower()
+    return string_input in ("yes", "true", "t", "1")
+
+
+def parse_json_parameters(parameters):
+    """
+    From JSON with Unicodes, return a dictionary having strings as keys.
+    Loading from DB a JSON will return instead of string keys, unicodes.
+    """
+    params = json.loads(parameters)
+    new_params = {}
+    for key, value in six.iteritems(params):
+        new_params[str(key)] = value
+    return new_params
+
+
 def format_timedelta(timedelta, most_significant2=True):
     """
     Format a datetime.timedelta.
@@ -166,12 +175,6 @@ def format_timedelta(timedelta, most_significant2=True):
     return ' '.join(fragments)
 
 
-def string2bool(string_input):
-    """ Convert given string into boolean value."""
-    string_input = str(string_input).lower()
-    return string_input in ("yes", "true", "t", "1")
-
-
 class TVBJSONEncoder(json.JSONEncoder):
     """
     Custom encoder class. Referring towards "to_json" method, when found, or default behaviour otherwise.
@@ -192,6 +195,13 @@ class TVBJSONEncoder(json.JSONEncoder):
 
 ################## MATLAB related method start here ###############
 
+def no_matlab():
+    """
+    :return: True when Matlab/Octave path hasn't been set or not existent installation.
+    """
+    return (not TvbProfile.current.MATLAB_EXECUTABLE) or get_matlab_executable() is None
+
+
 def get_matlab_executable():
     """
     Check If MATLAB is installed on current system.
