@@ -29,14 +29,13 @@
 #
 
 import os
-import shutil
 
 from tvb.core.neocom import h5
 from tvb.interfaces.rest.client.client_decorators import handle_response
 from tvb.interfaces.rest.client.main_api import MainApi
+from tvb.interfaces.rest.commons.files_helper import create_temp_folder
 from tvb.interfaces.rest.commons.strings import RequestFileKey
 from tvb.interfaces.rest.commons.strings import RestLink, LinkPlaceholder
-from tvb.interfaces.rest.commons.files_helper import create_temp_folder
 from tvb.storage.storage_interface import StorageInterface
 
 
@@ -48,8 +47,8 @@ class SimulationApi(MainApi):
 
         h5.store_view_model(session_stored_simulator, temporary_folder)
         zip_folder_path = os.path.join(temp_folder, RequestFileKey.SIMULATION_FILE_NAME.value)
-        StorageInterface().zip_folder(zip_folder_path, temporary_folder)
-        shutil.rmtree(temporary_folder)
+        StorageInterface().write_zip_folder(zip_folder_path, temporary_folder)
+        StorageInterface.remove_folder(temporary_folder)
 
         file_obj = open(zip_folder_path, 'rb')
         return self.secured_request().post(self.build_request_url(RestLink.FIRE_SIMULATION.compute_url(True, {
